@@ -46,8 +46,8 @@ type CmdConfig struct {
 	Images            func() do.ImagesService
 	ImageActions      func() do.ImageActionsService
 	LoadBalancers     func() do.LoadBalancersService
-	FloatingIPs       func() do.FloatingIPsService
-	FloatingIPActions func() do.FloatingIPActionsService
+	ReservedIPs       func() do.ReservedIPsService
+	ReservedIPActions func() do.ReservedIPActionsService
 	Droplets          func() do.DropletsService
 	DropletActions    func() do.DropletActionsService
 	Domains           func() do.DomainsService
@@ -95,8 +95,8 @@ func NewCmdConfig(ns string, dc doctl.Config, out io.Writer, args []string, init
 			c.Regions = func() do.RegionsService { return do.NewRegionsService(godoClient) }
 			c.Images = func() do.ImagesService { return do.NewImagesService(godoClient) }
 			c.ImageActions = func() do.ImageActionsService { return do.NewImageActionsService(godoClient) }
-			c.FloatingIPs = func() do.FloatingIPsService { return do.NewFloatingIPsService(godoClient) }
-			c.FloatingIPActions = func() do.FloatingIPActionsService { return do.NewFloatingIPActionsService(godoClient) }
+			c.ReservedIPs = func() do.ReservedIPsService { return do.NewReservedIPsService(godoClient) }
+			c.ReservedIPActions = func() do.ReservedIPActionsService { return do.NewReservedIPActionsService(godoClient) }
 			c.Droplets = func() do.DropletsService { return do.NewDropletsService(godoClient) }
 			c.DropletActions = func() do.DropletActionsService { return do.NewDropletActionsService(godoClient) }
 			c.Domains = func() do.DomainsService { return do.NewDomainsService(godoClient) }
