@@ -168,8 +168,8 @@ func computeCmd() *Command {
 	cmd.AddCommand(Droplet())
 	cmd.AddCommand(Domain())
 	cmd.AddCommand(Firewall())
-	cmd.AddCommand(FloatingIP())
-	cmd.AddCommand(FloatingIPAction())
+	cmd.AddCommand(ReservedIP())
+	cmd.AddCommand(ReservedIPAction())
 	cmd.AddCommand(Images())
 	cmd.AddCommand(ImageAction())
 	cmd.AddCommand(LoadBalancer())
